nvector._core.n_E2lat_lon — nvector 0.7.5 documentation

# nvector._core.n_E2lat_lon

`n_E2lat_lon`(n_E, R_Ee=None)

  Converts n-vector to latitude and longitude.

  Parameters
    n_E: 3 x n array

      n-vector [no unit] decomposed in E.

    R_Ee3 x 3 array

      rotation matrix defining the axes of the coordinate frame E.

  Returns
    latitude, longitude: real scalars or vectors of length n.

      Geodetic latitude and longitude given in [rad]

  See also

  `lat_lon2n_E`